pub enum NoDomainError {}Expand description
Marker type for API errors with no domain-specific variants
This type is used as the default for ApiError<E> when no domain-specific
errors are needed. It can never be constructed, so the Domain variant
is effectively unused.